# BenchMerge.py
""" Shows how to use the timeit module to check the
running time of a function call. The functions involved
are Merge1 and Merge2 that are defined in the module
ShowMergeSort. 
"""

from timeit import *

# The set-up code is placed in a doc string.

OurSetUpCode = '''
from random import randint as randi
from ShowMergeSort import Merge1
from ShowMergeSort import Merge2
n = 100000
s = [randi(0,10*n) for i in range(n)]
s.sort()
t = [randi(0,10*n) for i in range(n)]
t.sort()

'''

# The Benchmark code is also placed in a doc string.
# Since we have two functions to benchmark, we have
# two such doc strings.

BenchMerge1 = """
u=Merge1(s,t)
"""

BenchMerge2 = """
u = Merge2(s,t)
"""

# m is the number of times the benchmark code is run for
# each timing. Because of clock granularity, larger values
# are needed for benchmark codes that runn very quickly

m = 1

# p is the number of timings that are run. Larger values
# help insure among the timings there will one that accurately
# reflects the true running time.(Background activity on the computer
# might diminish perfromance.

p = 3

n = 10000

print '\nTimes for Merge1 with n = %1d' % n
tMerge1Times = Timer(BenchMerge1, setup=OurSetUpCode).repeat(p,m)
for k in range(p):
    print '  %8.5f' % tMerge1Times[k]
    
print '\nTimes for Merge2 with n = %1d' % n
tMerge2Times = Timer(BenchMerge2, setup=OurSetUpCode).repeat(p,m)
for k in range(p):
    print '  %8.5f' % tMerge2Times[k]
    

    
